aind\_metadata\_mapper.fip package
==================================

Submodules
----------

aind\_metadata\_mapper.fip.models module
----------------------------------------

.. automodule:: aind_metadata_mapper.fip.models
   :members:
   :undoc-members:
   :show-inheritance:

aind\_metadata\_mapper.fip.session module
-----------------------------------------

.. automodule:: aind_metadata_mapper.fip.session
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aind_metadata_mapper.fip
   :members:
   :undoc-members:
   :show-inheritance:
